==> paraview_5.9.0.orig.tar.xz: paraview-5.9.0/Qt/ApplicationComponents/pqLightPropertyWidget.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqLightPropertyWidget.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqLightPropertyWidget_h
#define pqLightPropertyWidget_h

#include "pqInteractivePropertyWidget.h"

/**
* pqLightPropertyWidget is a custom property widget that uses
* "LightWidgetRepresentation" to help users interactively set a light properties in
* space. To use this widget for a property group
* (vtkSMPropertyGroup), use "InteractiveLight" as the "panel_widget" in the
* XML configuration for the proxy. The property group should have properties for
* following functions:
* \li \c Positional: a 1-tuple vtkSMIntVectorProperty with a vtkSMEnumerationDomain
* that will be use to show the positional cone or not.
* \li \c WorldPosition: a 3-tuple vtkSMDoubleVectorProperty that will be linked to the
* origin of the interactive light.
* \li \c FocalPoint: a 3-tuple vtkSMDoubleVectorProperty that will be linked to the
* the focal point of the interactive light.
* \li \c FocalPoint: a 1-tuple vtkSMDoubleVectorProperty with a vtkSMDoubleRangeDomain
* that will be linked to the cone angle of the interactive light.
*/
class PQAPPLICATIONCOMPONENTS_EXPORT pqLightPropertyWidget : public pqInteractivePropertyWidget
{
  Q_OBJECT
  typedef pqInteractivePropertyWidget Superclass;

public:
  pqLightPropertyWidget(vtkSMProxy* proxy, vtkSMPropertyGroup* smgroup, QWidget* parent = 0);
  ~pqLightPropertyWidget() override;

protected Q_SLOTS:
  void placeWidget() override {}

  /**
   * Update the visibility state of the different elements of the property widget
   */
  void updateVisibilityState();

private:
  Q_DISABLE_COPY(pqLightPropertyWidget);

  class pqInternals;
  pqInternals* Internals;
};

#endif

==> paraview_5.11.0+dfsg.orig.tar.xz: paraview-5.11.0+dfsg/Qt/ApplicationComponents/pqLightPropertyWidget.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqLightPropertyWidget.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqLightPropertyWidget_h
#define pqLightPropertyWidget_h

#include "pqInteractivePropertyWidget.h"

/**
 * pqLightPropertyWidget is a custom property widget that uses
 * "LightWidgetRepresentation" to help users interactively set a light properties in
 * space. To use this widget for a property group
 * (vtkSMPropertyGroup), use "InteractiveLight" as the "panel_widget" in the
 * XML configuration for the proxy. The property group should have properties for
 * following functions:
 * \li \c Positional: a 1-tuple vtkSMIntVectorProperty with a vtkSMEnumerationDomain
 * that will be use to show the positional cone or not.
 * \li \c WorldPosition: a 3-tuple vtkSMDoubleVectorProperty that will be linked to the
 * origin of the interactive light.
 * \li \c FocalPoint: a 3-tuple vtkSMDoubleVectorProperty that will be linked to the
 * the focal point of the interactive light.
 * \li \c FocalPoint: a 1-tuple vtkSMDoubleVectorProperty with a vtkSMDoubleRangeDomain
 * that will be linked to the cone angle of the interactive light.
 */
class PQAPPLICATIONCOMPONENTS_EXPORT pqLightPropertyWidget : public pqInteractivePropertyWidget
{
  Q_OBJECT
  typedef pqInteractivePropertyWidget Superclass;

public:
  pqLightPropertyWidget(vtkSMProxy* proxy, vtkSMPropertyGroup* smgroup, QWidget* parent = nullptr);
  ~pqLightPropertyWidget() override;

protected Q_SLOTS:
  void placeWidget() override {}

  /**
   * Update the visibility state of the different elements of the property widget
   */
  void updateVisibilityState();

private:
  Q_DISABLE_COPY(pqLightPropertyWidget);

  class pqInternals;
  pqInternals* Internals;
};

#endif
